@@ -1,10 +1,10 @@
 from __future__ import annotations
 
-from typing import Any, get_args
+from typing import Any
 
 from mknodes.basenodes import mknode
 from mknodes.data import datatypes
-from mknodes.utils import log, reprhelpers, resources, xmlhelpers
+from mknodes.utils import log, resources, xmlhelpers
 
 
 logger = log.get_logger(__name__)
@@ -14,7 +14,7 @@ class MkCompactAdmonition(mknode.MkNode):
     """Compact admonition info box."""
 
     ICON = "octicons/info-16"
-    CSS = [resources.CSSFile("css/compactadmonition.css")]
+    CSS = [resources.CSSFile("compactadmonition.css")]
 
     def __init__(
         self,
@@ -34,9 +34,6 @@ class MkCompactAdmonition(mknode.MkNode):
         self.typ = typ
         super().__init__(**kwargs)
 
-    def __repr__(self):
-        return reprhelpers.get_repr(self, text=self.text, typ=self.typ)
-
     def _to_markdown(self) -> str:
         kls = f"mdx-grid-wrapper mdx-admo--{self.typ}" if self.typ else "mdx-grid-wrapper"
         root = xmlhelpers.Div(kls)
@@ -45,16 +42,6 @@ class MkCompactAdmonition(mknode.MkNode):
         text_div.text = str(self.text)
         return root.to_string()
 
-    @classmethod
-    def create_example_page(cls, page):
-        import mknodes as mk
-
-        for typ in get_args(datatypes.AdmonitionTypeStr):
-            page += mk.MkHeader(f"Type '{typ}'", level=3)
-            content = f"This is type **{typ}**"
-            node = MkCompactAdmonition(typ=typ, text=content)
-            page += mk.MkReprRawRendered(node)
-
 
 if __name__ == "__main__":
     admonition = MkCompactAdmonition("FDSFDFSFS", typ="bug")
