@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Literal, get_args
+from typing import TYPE_CHECKING, Any, Literal
 
 from mknodes.basenodes import mkcontainer
-from mknodes.utils import log, reprhelpers, resources
+from mknodes.utils import log, resources
 
 
 if TYPE_CHECKING:
@@ -24,46 +24,37 @@ class MkCritic(mkcontainer.MkContainer):
         self,
         content: str | mk.MkNode | list,
         *,
-        mark: CriticMarkStr = "highlight",
+        typ: CriticMarkStr = "highlight",
         **kwargs: Any,
     ):
         """Constructor.
 
         Arguments:
             content: Content to mark
-            mark: type of mark
+            typ: Mark type
             kwargs: Keyword arguments passed to parent
         """
         super().__init__(content=content, **kwargs)
-        self.mark = mark
+        self.typ = typ
 
-    def __repr__(self):
-        return reprhelpers.get_repr(self, content=self.items, mark=self.mark)
+    @property
+    def marks(self):
+        match self.typ:
+            case "addition":
+                return ("++", "++")
+            case "deletion":
+                return ("--", "--")
+            case "highlight":
+                return ("==", "==")
+            case "comment":
+                return (">>", "<<")
+            case _:
+                raise TypeError(self.typ)
 
     def _to_markdown(self) -> str:
-        match self.mark:
-            case "addition":
-                left, right = ("++", "++")
-            case "deletion":
-                left, right = ("--", "--")
-            case "highlight":
-                left, right = ("==", "==")
-            case "comment":
-                left, right = (">>", "<<")
-            case _:
-                raise TypeError(self.mark)
+        left, right = self.marks
         return f"{{{left}\n\n{super()._to_markdown()}\n\n{right}}}"
 
-    @classmethod
-    def create_example_page(cls, page):
-        import mknodes as mk
-
-        page += "The MkCritic node can be used to display text diffs."
-        for typ in get_args(CriticMarkStr):
-            node = MkCritic(f"This is type {typ}", mark=typ)
-            page += mk.MkHeader(f"Type {typ!r}", level=3)
-            page += mk.MkReprRawRendered(node)
-
 
 if __name__ == "__main__":
     mkcritic = MkCritic("hello")
