@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import Any
 
 from mknodes.basenodes import mknode
-from mknodes.utils import log, reprhelpers, resources
+from mknodes.utils import log, resources
 
 
 logger = log.get_logger(__name__)
@@ -37,21 +37,10 @@ class MkKeys(mknode.MkNode):
             case list():
                 self.keys = [i.lower() for i in keys]
 
-    def __repr__(self):
-        return reprhelpers.get_repr(self, keys=self.keys)
-
     def _to_markdown(self) -> str:
         key_str = "+".join(self.keys)
         return f"++{key_str}++"
 
-    @classmethod
-    def create_example_page(cls, page):
-        import mknodes as mk
-
-        page += mk.MkAdmonition("MkKeys can be used to show Key combinations.")
-        page += mk.MkReprRawRendered(MkKeys("M+k+K+e+y+s"))
-        page += mk.MkReprRawRendered(MkKeys("Ctrl+A"))
-
 
 if __name__ == "__main__":
     keys = MkKeys(keys="Ctrl+A")
