@@ -1,13 +1,17 @@
 from __future__ import annotations
 
+import abc
+
+from collections.abc import Callable, Mapping, MutableMapping
 import dataclasses
+import datetime
 import pathlib
 import types
-
 from typing import Any
 
 from griffe.dataclasses import Alias, Module
 
+from mknodes import paths
 import mknodes as mk
 
 from mknodes.data import buildsystems, commitconventions, installmethods, tools
@@ -18,7 +22,8 @@ from mknodes.info import (
     packageregistry,
     pyproject,
 )
-from mknodes.utils import clihelpers, log, superdict
+from mknodes.info.cli import commandinfo
+from mknodes.utils import log, superdict
 
 
 logger = log.get_logger(__name__)
@@ -46,12 +51,27 @@ class GitContext(Context):
     """Name of the main branch of the repo (`master` / `main`)."""
     repo_name: str = ""
     """Name of the git folder."""
-    last_commits: list = dataclasses.field(default_factory=list)
+    commits: list = dataclasses.field(default_factory=list)
     """List of last commits (Commit objects from `GitPython`)."""
     repo_hoster: str = ""
     """Name of the code hoster (for example `GitHub`)"""
     edit_uri: str | None = None
     """Edit uri (depends on code hoster)."""
+    current_sha: str = ""
+    """SHA of last commit."""
+    current_committer: str = ""
+    """Committer name for last commit."""
+    current_date_committed: datetime.datetime | None = None
+    """Date committed for last commit."""
+    current_author: str = ""
+    """Author email for last commit."""
+    current_date_authored: datetime.datetime | None = None
+    """Date authored for last commit."""
+    last_version: str | None = None
+    """Name of last commit tag."""
+
+    def __repr__(self):
+        return f"GitContext({self.repo_name!r}: {self.main_branch!r})"
 
 
 @dataclasses.dataclass
@@ -76,6 +96,9 @@ class ThemeContext(Context):
     css_default_fg: str = ""
     css_default_bg: str = ""
 
+    def __repr__(self):
+        return f"ThemeContext({self.name!r})"
+
 
 # @dataclasses.dataclass
 # class PyProjectContext(Context):
@@ -96,7 +119,7 @@ class ThemeContext(Context):
 #     """Commit types defined in pyproject mknodes section *[pyproject]*"""
 #     extras_descriptions: dict[str, str] = dataclasses.field(default_factory=dict)
 #     """Descriptions for extras, defined in pyproject mknodes section *[pyproject]*"""
-#     package_repos: list[installmethods.InstallMethodStr] = dataclasses.field(
+#     package_repos: list[installmethods.InstallMethod] = dataclasses.field(
 #         default_factory=list,
 #     )
 #     """Package repositories the distribution is distributed on."""
@@ -143,7 +166,7 @@ class PackageContext(Context):
     """PackageInfos for the dependencies."""
     extras: dict[str, folderinfo.PackageExtra] = dataclasses.field(default_factory=dict)
     """The extras of the distribution."""
-    urls: dict[str, str] = dataclasses.field(default_factory=dict)
+    urls: Mapping[str, str] = dataclasses.field(default_factory=dict)
     """A set of URLs related to the distribution."""
     homepage: str = ""
     """The main website of the distribution."""
@@ -179,7 +202,7 @@ class PackageContext(Context):
     """A dictionary containing the entry points of the distribution."""
     cli: str | None = None
     """The cli package name used by the distribution."""
-    cli_info: clihelpers.CommandInfo | None = None
+    cli_info: commandinfo.CommandInfo | None = None
     """An object containing information about all cli commands."""
 
     # required_packages: dict[PackageInfo, packagehelpers.Dependency] =
@@ -196,18 +219,23 @@ class PackageContext(Context):
     )
     """The tool section of the pyproject file.
 
-    Comes as a SuperDict. (A Mutable mapping with extended capabilities) *[pyproject]*"""
+    Comes as a SuperDict. (A Mutable mapping with extended capabilities) *[pyproject]*
+    """
     line_length: int | None = None
     """The line length, if defined by any popular tool *[pyproject]*"""
     commit_types: list[commitconventions.CommitTypeStr] = dataclasses.field(
         default_factory=list,
     )
     """Commit types defined in pyproject mknodes section *[pyproject]*"""
-    package_repos: list[installmethods.InstallMethodStr] = dataclasses.field(
+    package_repos: list[installmethods.InstallMethod] = dataclasses.field(
         default_factory=list,
     )
     """Package repositories the distribution is distributed on.
-    Defined in pyproject mknodes section *[pyproject]*"""
+    Defined in pyproject mknodes section *[pyproject]*
+    """
+
+    def __repr__(self):
+        return f"PackageContext({self.distribution_name!r})"
 
 
 @dataclasses.dataclass
@@ -234,7 +262,7 @@ class GitHubContext(Context):
     """The follower count of the user."""
     gravatar_id: str | None = None
     """The gravatar id associated with the user."""
-    hireable: bool = False
+    hireable: bool | None = None
     """Whether the user is hireable."""
     location: str | None = None
     """The user location, as set on GitHub."""
@@ -243,6 +271,56 @@ class GitHubContext(Context):
     twitter_username: str | None = None
     """The twitter username."""
 
+    def __repr__(self):
+        return f"GitHubContext({self.repo_name!r})"
+
+
+@dataclasses.dataclass
+class EnvironmentContext(MutableMapping, metaclass=abc.ABCMeta):
+    loader: dict = dataclasses.field(default_factory=dict)
+    block_start_string: str | None = None
+    block_end_string: str | None = None
+    variable_start_string: str | None = None
+    variable_end_string: str | None = None
+    undefined: str | None = None
+
+    def __getitem__(self, value):
+        return getattr(self, value)
+
+    def __setitem__(self, index, value):
+        setattr(self, index, value)
+
+    def __delitem__(self, index):
+        setattr(self, index, None)
+
+    def __len__(self):
+        return len(dataclasses.fields(self))
+
+    def __iter__(self):
+        return iter(i.name for i in dataclasses.fields(self))
+
+
+@dataclasses.dataclass
+class ContextConfig(Mapping, metaclass=abc.ABCMeta):
+    repo_url: str = "."
+    clone_depth: int = 100
+    jinja_config: Mapping[str, Any] = dataclasses.field(default_factory=dict)
+    build_fn: str | Callable = paths.DEFAULT_BUILD_FN
+    base_url: str = ""
+    use_directory_urls: bool = True
+
+    def __getitem__(self, value):
+        return getattr(self, value)
+
+    def __setitem__(self, index, value):
+        setattr(self, index, value)
+
+    def __len__(self):
+        return len(dataclasses.fields(self))
+
+    def __iter__(self):
+        return iter(i.name for i in dataclasses.fields(self))
+
 
 @dataclasses.dataclass
 class ProjectContext(Context):
@@ -260,18 +338,47 @@ class ProjectContext(Context):
         default_factory=linkprovider.LinkProvider,
     )
     """Link source."""
-    env: mk.Environment = dataclasses.field(
-        default_factory=lambda: mk.Environment(load_templates=True),
-    )
+    env_config: dict = dataclasses.field(default_factory=dict)
     # resources: Resources = dataclasses.field(default_factory=Resources)
     # pyproject: pyproject.PyProject = dataclasses.field(
     #     default_factory=pyproject.PyProject,
     # )
 
-    def __post_init__(self):
-        self.env.filters["get_link"] = self.links.get_link
-        self.env.filters["get_url"] = self.links.get_url
-        self.env.globals |= self.as_dict()
+    @classmethod
+    def for_config(
+        cls,
+        *args: dict,
+        theme_context: ThemeContext | None = None,
+        **kwargs: Any,
+    ):
+        """The main project to create a website.
+
+        Arguments:
+            args: Config mapping
+            theme_context: Optional theme context
+            kwargs: Keyword arguments to override config values
+        """
+        from mknodes.info import folderinfo as fi, linkprovider, reporegistry
+
+        cfg = {k: v for d in args for k, v in d.items()}
+        cfg.update(kwargs)
+        links = linkprovider.LinkProvider(
+            base_url=cfg.get("base_url", ""),
+            use_directory_urls=cfg.get("use_directory_urls", True),
+            include_stdlib=True,
+        )
+        git_repo = reporegistry.get_repo(
+            cfg.get("repo_url") or ".",
+            clone_depth=cfg.get("clone_depth", 100),
+        )
+        folderinfo = fi.FolderInfo(git_repo.working_dir)
+        return cls(
+            metadata=folderinfo.context,
+            git=folderinfo.git.context,
+            theme=theme_context or ThemeContext(),
+            links=links,
+            env_config=cfg.get("env_config", {}),
+        )
 
     def populate_linkprovider(self):
         if self.metadata.mkdocs_config is None:
@@ -295,55 +402,48 @@ class ProjectContext(Context):
         )
 
 
-default_package_context = PackageContext(
-    pretty_name="MkNodes",
-    version="1.0.0",
-    distribution_name="mknodes",
-    summary="Don't write docs. Code them.",
-    description="Long text with description.",
-    author_name="Philipp Temminghoff",
-    author_email="philipptemminghoff@gmail.com",
-    license_name="MIT",
-    required_python_version=">= 3.11",
-    homepage="",
-    cli="typer",
-    module=mk,
-    repository_url="https://github.com/phil65/mknodes/",
-    repository_username="phil65",
-    repository_name="mknodes",
-    inventory_url="https://github.io/phil65/mknodes/objects.inv",
-)
-
-
-default_git_context = GitContext(
-    main_branch="main",
-    repo_name="mknodes",
-    repo_hoster="GitHub",
-    edit_uri="edit/main/docs/",
-)
-
-
-default_theme_context = ThemeContext(
-    name="material",
-    primary_color="AAAAAA",
-    text_color="#000000",
-)
-
-
-default_github_context = GitHubContext(
-    default_branch="main",
-    repo_name="mknodes",
-)
-
-
 def get_default_project_context():
+    default_git_context = GitContext(
+        main_branch="main",
+        repo_name="mknodes",
+        repo_hoster="GitHub",
+        edit_uri="edit/main/docs/",
+    )
+    default_theme_context = ThemeContext(
+        name="material",
+        primary_color="AAAAAA",
+        text_color="#000000",
+    )
+    default_github_context = GitHubContext(
+        default_branch="main",
+        repo_name="mknodes",
+    )
+    default_package_context = PackageContext(
+        pretty_name="MkNodes",
+        version="1.0.0",
+        distribution_name="mknodes",
+        summary="Don't write docs. Code them.",
+        description="Long text with description.",
+        author_name="Philipp Temminghoff",
+        author_email="philipptemminghoff@gmail.com",
+        license_name="MIT",
+        required_python_version=">= 3.11",
+        homepage="",
+        cli="typer",
+        module=mk,
+        repository_url="https://github.com/phil65/mknodes/",
+        repository_username="phil65",
+        repository_name="mknodes",
+        inventory_url="https://github.io/phil65/mknodes/objects.inv",
+    )
+
     return ProjectContext(
         metadata=default_package_context,
         git=default_git_context,
         github=default_github_context,
         theme=default_theme_context,
         links=linkprovider.LinkProvider(),
-        env=mk.Environment(load_templates=True),
+        env_config={},
         # resources=Resources(),
     )
 
