@@ -25,10 +25,19 @@ def get_module(module: str | types.ModuleType) -> griffe.Module | Alias:
     return registry.get_module(module)
 
 
-class GriffeRegistry(MutableMapping, metaclass=ABCMeta):
-    """Registry for PackageInfos.
+def get_class(klass: str | type) -> griffe.Class | Alias:
+    """Return info for given klass from registry.
 
-    Used for caching all loaded Package information.
+    Arguments:
+        klass: Name of the klass
+    """
+    return registry.get_class(klass)
+
+
+class GriffeRegistry(MutableMapping, metaclass=ABCMeta):
+    """Registry for Griffe Modules.
+
+    Used for accessing / caching all loaded Griffe objects.
     The registry will always only create the Griffe module for the top-level module
     and then use griffe_module[submodule] or griffe_module[klass] to get the
     griffe instances. That should enable the best cache behaviour.
@@ -41,7 +50,13 @@ class GriffeRegistry(MutableMapping, metaclass=ABCMeta):
         ```
     """
 
-    def __init__(self):
+    def __init__(self, expand_wildcards: bool = True):
+        """Instanciate the registry.
+
+        Arguments:
+            expand_wildcards: Whether to expand wildcard imports for the Modules
+        """
+        self.expand_wildcards = expand_wildcards
         self._modules: dict[str, griffe.Module] = {}
 
     def __getitem__(self, value):
@@ -82,7 +97,10 @@ class GriffeRegistry(MutableMapping, metaclass=ABCMeta):
         if module_name not in self._modules:
             parser = Parser(docstring_style)
             loader = GriffeLoader(docstring_parser=parser)
-            self._modules[module_name] = loader.load_module(module_name)
+            griffe_mod = loader.load(module_name)
+            if self.expand_wildcards:
+                loader.expand_wildcards(griffe_mod, external=True)
+            self._modules[module_name] = griffe_mod
         griffe_mod = self._modules[module_name]
         return griffe_mod[sub_mod_path] if sub_mod_path else griffe_mod
 
@@ -98,11 +116,16 @@ class GriffeRegistry(MutableMapping, metaclass=ABCMeta):
             docstring_style: Docstring style
         """
         if isinstance(klass, type):
-            mod_name, sub_mod_path = klass.__module__.split(".", 1)
+            mod_name = klass.__module__
+            if "." in mod_name:
+                mod_name, sub_mod_path = mod_name.split(".", 1)
+            else:
+                mod_name, sub_mod_path = mod_name, ""
             qual_name = klass.__qualname__
             kls_name = f"{sub_mod_path}.{qual_name}" if sub_mod_path else qual_name
         else:
-            mod_name, kls_name = klass.split(".", 1)
+            parts = klass.split(".", 1)
+            mod_name, kls_name = parts if len(parts) > 1 else ("builtins", parts[0])
         module = self.get_module(mod_name, docstring_style=docstring_style)
         return module[kls_name]
 
