@@ -1,13 +1,11 @@
 from __future__ import annotations
 
-from collections.abc import Sequence
-
-import jinja2
-
 from mknodes.info import yamlfile
 
 
 class MkDocsConfigFile(yamlfile.YamlFile):
+    SCHEMA = "https://json.schemastore.org/mkdocs-1.0.json"
+
     @property
     def theme(self):
         """Return theme section."""
@@ -33,6 +31,11 @@ class MkDocsConfigFile(yamlfile.YamlFile):
         """Return the MkDocStrings config section."""
         return self.get_section("plugins", "mkdocstrings", "handlers", "python") or {}
 
+    def remove_plugin(self, name: str):
+        for plg in self.plugins:
+            if plg == name or (isinstance(plg, dict) and next(iter(plg.keys())) == name):
+                self.plugins.remove(plg)
+
     def update_mknodes_section(
         self,
         repo_url: str | None = None,
@@ -55,19 +58,6 @@ class MkDocsConfigFile(yamlfile.YamlFile):
                 if clone_depth is not None:
                     plugin["mknodes"]["clone_depth"] = clone_depth
 
-    def get_loaders(self) -> Sequence[jinja2.BaseLoader]:
-        from mknodes.jinja import loaders
-
-        jinja_loaders: list[jinja2.BaseLoader] = [
-            loaders.FileSystemLoader(searchpath=self._data.get("docs_dir", "docs")),
-        ]
-        for loader_dct in self.mknodes_config.get("loaders", []):
-            dct = loader_dct.copy()
-            kls = loaders.LOADERS[dct.pop("name")]
-            loader = kls(**dct)
-            jinja_loaders.append(loader)
-        return jinja_loaders
-
     def get_inventory_infos(self) -> list[dict]:
         """Returns list of dicts containing inventory info.
 
@@ -88,4 +78,3 @@ class MkDocsConfigFile(yamlfile.YamlFile):
 
 if __name__ == "__main__":
     info = MkDocsConfigFile("mkdocs.yml")
-    print(info.get_loaders())
