@@ -12,10 +12,9 @@ from mknodes.manual import (
 
 def build(project: mk.Project[mk.MaterialTheme]) -> mk.MkNav:
     build = Build()
-    nav = project.get_root()
     project.linkprovider.add_inv_file("https://mkdocstrings.github.io/objects.inv")
     build.on_theme(project.theme)
-    return build.on_root(nav) or nav
+    return build.on_root(project.root) or project.root
 
 
 class Build:
@@ -36,3 +35,14 @@ class Build:
         nav += templating_section.nav
         nav += dev_section.nav
         return nav
+
+
+if __name__ == "__main__":
+    import mknodes as mk
+
+    nav = mk.MkNav()
+    bld = Build()
+    bld.on_root(nav)
+    for node in nav.iter_nodes():
+        if isinstance(node, mk.MkPage):
+            print(node)
