@@ -28,7 +28,7 @@ class MkDefaultWebsite(mk.MkNav):
         self.page_template.announcement_bar = mk.MkMetadataBadges("websites")
         if self.ctx.metadata.cli:
             page = self.add_page("CLI", hide="nav")
-            page += mk.MkClickDoc(show_subcommands=True)
+            page += mk.MkCliDoc(show_subcommands=True)
 
         nav = self.add_nav("Development")
 
@@ -50,9 +50,6 @@ class MkDefaultWebsite(mk.MkNav):
         page += mk.MkDependencyTable()
         page += mk.MkPipDepTree(direction="LR")
 
-        page = nav.add_page("Module overview")
-        page += mk.MkModuleOverview()
-
         if "mkdocs.plugins" in self.ctx.metadata.entry_points:
             page = nav.add_page("MkDocs Plugins")
             page += mk.MkPluginFlow()
@@ -61,19 +58,8 @@ class MkDefaultWebsite(mk.MkNav):
         page = nav.add_page("License", hide="toc")
         page += node
 
-    @classmethod
-    def for_project(cls, project, **kwargs):
-        root = cls(context=project.context, **kwargs)
-        project.set_root(root)
-        return root
-
 
 if __name__ == "__main__":
-    theme = mk.MaterialTheme()
-    doc = MkDefaultWebsite.for_project(
-        mk.Project(theme=theme),
-        static_pages={
-            "Usage": "https://raw.githubusercontent.com/mkdocs/mkdocs/master/docs/getting-started.md",
-        },
-    )
+    url = "https://raw.githubusercontent.com/mkdocs/mkdocs/master/docs/getting-started.md"
+    doc = MkDefaultWebsite.with_context(static_pages={"Usage": url})
     print(doc)
