@@ -15,25 +15,12 @@ class MkEmptyWebsite(mknav.MkNav):
         import mknodes as mk
 
         page = self.add_page(is_index=True, title="Overview", hide="toc")
-        page += mk.MkText(r"metadata.description", is_jinja_expression=True)
+        page += mk.MkText(self.ctx.metadata.description)
         static_pages = static_pages or {}
         self.parse.json(static_pages)
 
-    @classmethod
-    def for_project(cls, project, **kwargs):
-        root = cls(context=project.context, **kwargs)
-        project.set_root(root)
-        return root
-
 
 if __name__ == "__main__":
-    import mknodes as mk
-
-    theme = mk.MaterialTheme()
-    doc = MkEmptyWebsite.for_project(
-        mk.Project(theme=theme),
-        static_pages={
-            "Usage": "https://raw.githubusercontent.com/mkdocs/mkdocs/master/docs/getting-started.md",
-        },
-    )
+    url = "https://raw.githubusercontent.com/mkdocs/mkdocs/master/docs/getting-started.md"
+    doc = MkEmptyWebsite.with_context(static_pages={"Usage": url})
     print(doc)
