@@ -10,8 +10,8 @@ from typing import TYPE_CHECKING, Any
 from mknodes.basenodes import mknode
 from mknodes.data.datatypes import PageStatusStr
 from mknodes.navs import navigation, navparser, navrouter
-from mknodes.pages import metadata, mkpage, pagetemplate
-from mknodes.utils import inspecthelpers, log, reprhelpers, resources
+from mknodes.pages import metadata as metadata_, mkpage, pagetemplate
+from mknodes.utils import inspecthelpers, log, reprhelpers
 
 
 if TYPE_CHECKING:
@@ -30,16 +30,13 @@ class MkNav(mknode.MkNode):
     """
 
     ICON = "material/navigation-outline"
-    REQUIRED_PLUGINS = [
-        resources.Plugin("literate_nav"),
-        resources.Plugin("section_index"),
-    ]
 
     def __init__(
         self,
         section: str | None = None,
         *,
         filename: str = "SUMMARY.md",
+        metadata: dict | None = None,
         **kwargs: Any,
     ):
         """Constructor.
@@ -47,9 +44,10 @@ class MkNav(mknode.MkNode):
         Arguments:
             section: Section name for the Nav
             filename: FileName for the resulting nav
+            metadata: Metadata for the nav. Child pages will inherit this.
             kwargs: Keyword arguments passed to parent
         """
-        self.section = section
+        self.title = section
         self.filename = filename
         self.nav = navigation.Navigation()
         """Navigation object containing all child items."""
@@ -57,7 +55,7 @@ class MkNav(mknode.MkNode):
         """Router used for decorator routing."""
         self.parse = navparser.NavParser(self)
         """Parser object used to build Navs from different data / directory structures."""
-        self.metadata = metadata.Metadata()
+        self.metadata = metadata_.Metadata(metadata or {})
         """Page Metadata."""
         self.page_template = pagetemplate.PageTemplate(parent=self, extends="main.html")
         super().__init__(**kwargs)
@@ -65,8 +63,8 @@ class MkNav(mknode.MkNode):
             self.metadata["created"] = inspecthelpers.get_stack_info(frame, level=1)
 
     def __repr__(self):
-        section = self.section or "<root>"
-        return reprhelpers.get_repr(self, section=section, filename=self.filename)
+        title = self.title or "<root>"
+        return reprhelpers.get_repr(self, section=title, filename=self.filename)
 
     # The child items are managed by the Navigation object. We forward relevant calls
     # to the Navigation instance.
@@ -81,10 +79,10 @@ class MkNav(mknode.MkNode):
         del self.nav[index]
 
     # def __len__(self):
-    #     return len(self.nav.all_items)
+    #     return len(self.children)
 
     def __iter__(self):
-        yield from self.nav.all_items
+        yield from self.children
 
     @property
     def index_page(self) -> mk.MkPage | None:
@@ -95,14 +93,9 @@ class MkNav(mknode.MkNode):
     def index_page(self, value):
         value.parent = self
         self.nav.index_page = value
-
-    @property
-    def index_title(self):
-        return self.nav.index_title
-
-    @index_title.setter
-    def index_title(self, value):
-        self.nav.index_title = value
+        self.nav.index_page._is_index = True
+        if not self.nav.index_page.title:
+            self.nav.index_page.title = self.title or "Home"
 
     @property
     def children(self):
@@ -172,7 +165,7 @@ class MkNav(mknode.MkNode):
             tags: tags to show above the main headline and within the search preview
         """
         page = mkpage.MkPage(
-            title=title,
+            title=title or self.title or "Home" if is_index else title,
             is_index=is_index,
             is_homepage=is_homepage,
             path=path,
@@ -189,7 +182,6 @@ class MkNav(mknode.MkNode):
         )
         if is_index:
             self.index_page = page
-            self.index_title = title or self.section or "Home"
         else:
             self.nav.register(page)
         return page
@@ -201,8 +193,8 @@ class MkNav(mknode.MkNode):
         filter_by___all__: bool = False,
         recursive: bool = False,
         section_name: str | None = None,
-        class_page: type[mk.MkClassPage] | str | None = None,
-        module_page: type[mk.MkModulePage] | str | None = None,
+        class_template: str | None = None,
+        module_template: str | None = None,
         flatten_nav: bool = False,
     ) -> mk.MkDoc:
         """Add a module documentation to the Nav.
@@ -212,8 +204,8 @@ class MkNav(mknode.MkNode):
             filter_by___all__: Whether the documentation
             recursive: Whether to search modules recursively
             section_name: Override the name for the menu (default: module name)
-            class_page: Override for the default ClassPage
-            module_page: Override for the default ModulePage
+            class_template: Override for the default ClassPage template
+            module_template: Override for the default ModulePage template
             flatten_nav: Whether classes should be put into top-level of the nav
         """
         import mknodes as mk
@@ -224,8 +216,8 @@ class MkNav(mknode.MkNode):
             parent=self,
             section_name=section_name,
             recursive=recursive,
-            class_page=class_page,
-            module_page=module_page,
+            class_template=class_template,
+            module_template=module_template,
             flatten_nav=flatten_nav,
         )
         self.nav.register(nav)
