@@ -9,6 +9,8 @@ import re
 from typing import TYPE_CHECKING, Any
 from urllib import parse
 
+import upath
+
 from mknodes.basenodes import mkcode
 from mknodes.navs import mknav
 from mknodes.pages import mkpage
@@ -30,12 +32,13 @@ SECTION_RE = r"^\* (.*)"
 ARGS_KWARGS_RE = r".*\((.*)\)"  # get brace content
 
 
-def str2page(
+def str2node(
     path: str | os.PathLike,
     name: str | None = None,
-    **kwargs,
-) -> mk.MkPage:
-    """Parse given path, check for our -> syntax, and return a MkPage.
+    parent: mk.MkNode | None = None,
+    **kwargs: Any,
+) -> mk.MkPage | mk.MkNav:
+    """Parse given path, check for our -> syntax, and return a MkPage / MkNav.
 
     If -> is detected, return a MkPage containing given MkNode. Otherwise
     open / download the markdown file from given path and put that into an MkPage.
@@ -43,6 +46,7 @@ def str2page(
     Arguments:
         path: Path to build a MkPage for (Either path / URL or "-> MkNode")
         name: Name for given MkPage
+        parent: Parent for the MkPage
         kwargs: Additional metadata for MkPage
     """
     import mknodes as mk
@@ -52,19 +56,25 @@ def str2page(
     node_cls_name = path.removeprefix("->").strip().split("(")[0]
     if path.startswith("->") and node_cls_name in mk.__all__:
         node_cls = getattr(mk, node_cls_name)
-        page = mk.MkPage(name, **kwargs)
+        args = []
+        kwargs = {}
         if match := re.match(ARGS_KWARGS_RE, path):
             parts = match[1].split(",")
             args = [ast.literal_eval(i.strip()) for i in parts if "=" not in i]
             kwargs_iter = (i.strip().split("=", maxsplit=1) for i in parts if "=" in i)
             kwargs = {i[0]: ast.literal_eval(i[1]) for i in kwargs_iter}
-            msg = "Parsed: Node: %s, args: %s, kwargs: %s"
-            logger.debug(msg, node_cls.__name__, args, kwargs)
-            page += node_cls(*args, **kwargs)
-        else:
-            page += node_cls()
+        msg = "Parsed: Node: %s, args: %s, kwargs: %s"
+        logger.debug(msg, node_cls.__name__, args, kwargs)
+        if issubclass(node_cls, mk.MkNav | mk.MkPage):
+            return node_cls(*args, parent=parent, **kwargs)
+        page = mk.MkPage(name, parent=parent, **kwargs)
+        page += node_cls(*args, **kwargs)
         return page
-    return mk.MkPage.from_file(path, title=name, **kwargs)
+    if path.startswith(r"{{"):
+        page = mk.MkPage(name, parent=parent, **kwargs)
+        page += mk.MkText(path, render_jinja=True)
+        return page
+    return mk.MkPage.from_file(path, title=name, parent=parent, **kwargs)
 
 
 def from_list(
@@ -89,7 +99,7 @@ def from_list(
                         from_dict(val, nav.add_nav(name), base_path=base_path)
                     case str():
                         path = urljoin(base_path, val)
-                        nav += str2page(path=path, name=name)
+                        nav += str2node(path=path, name=name, parent=nav)
                     case list():
                         logger.debug("Adding nav %r", name)
                         if helpers.is_url(name):
@@ -120,7 +130,7 @@ def from_dict(
         match v:
             case str():
                 path = urljoin(base_path, v)
-                nav += str2page(path=path, name=k)
+                nav += str2node(path=path, name=k, parent=nav)
             case dict():
                 logger.debug("Adding nav %r", k)
                 from_dict(v, nav.add_nav(k), base_path=base_path)
@@ -228,15 +238,15 @@ class NavParser:
                     text = "\n".join(unindented)
                     subnav.parse.text(text, path=path, **kwargs)
                     page = subnav.add_page(is_index=True, **kwargs)
-                    page += pathlib.Path(m[2]).read_text()
+                    page += upath.UPath(m[2]).read_text()
                     msg = "Created subsection %s and loaded index page %s"
                     logger.debug(msg, m[1], m[2])
                     self._nav += subnav
 
                 # if not, add as regular page:
                 else:
-                    p = m[2] if m[2].startswith("->") else path.parent / m[2]
-                    page = str2page(path=p, name=m[1], parent=self._nav, **kwargs)
+                    p = m[2] if m[2].startswith(("->", r"{{")) else path.parent / m[2]
+                    page = str2node(path=p, name=m[1], parent=self._nav, **kwargs)
                     self._nav[m[1]] = page
                     logger.debug("Created page %s from %s", m[1], m[2])
 
@@ -287,8 +297,8 @@ class NavParser:
             elif path.name == "index.md":
                 logger.debug("Loaded index page from %s", path)
                 text = path.read_text(encoding="utf-8")
-                nav.index_page = mk.MkPage(path=path.name, content=text, **kwargs)
-                nav.index_title = nav.section or "Home"
+                title = nav.title or "Home"
+                nav.index_page = mk.MkPage(title, path=path.name, content=text, **kwargs)
             elif path.suffix in [".md", ".html"] and path.name != "SUMMARY.md":
                 text = path.read_text(encoding="utf-8")
                 rel_path = path.relative_to(folder)
@@ -325,7 +335,7 @@ class NavParser:
             elif path.suffix in [".py"]:
                 page = mkpage.MkPage(path=path.name, title=path.name, **kwargs)
                 content = path.read_text(encoding="utf-8")
-                page += mkcode.MkCode(content, language="py", linenums=1)
+                page += mkcode.MkCode(content, linenums=1)
                 self._nav += page
                 logger.debug("Loaded page from from %s", path)
         return self._nav
