@@ -2,7 +2,9 @@ from __future__ import annotations
 
 import dataclasses
 
-from mknodes.nodemods import modhelpers
+from jinjarope import htmlfilters
+
+from mknodes.nodemods import mod
 from mknodes.utils import helpers, resources
 
 
@@ -15,7 +17,7 @@ LIB = "https://cdn.jsdelivr.net/npm/simple-parallax-js@5.5.1/dist/simpleParallax
 
 
 @dataclasses.dataclass(frozen=True)
-class ParallaxEffect:
+class ParallaxEffect(mod.Mod):
     orientation: str = "up"
     scale: float = 1.5
     overflow: bool = False
@@ -26,11 +28,9 @@ class ParallaxEffect:
     def get_resources(self):
         file = resources.JSFile(LIB, is_library=True)
         dct = dataclasses.asdict(self)
-        js_map = modhelpers.format_js_map(dct)
-        script = resources.JSText(
-            SCRIPT % (self.css_class_names[0], js_map),
-            filename="parallax.js",
-        )
+        js_map = htmlfilters.format_js_map(dct)
+        text = SCRIPT % (self.css_class_names[0], js_map)
+        script = resources.JSText(text, filename="parallax.js")
         return resources.Resources(js=[file, script])
 
     @property
