@@ -4,18 +4,15 @@ import os
 
 from typing import Any
 
-from mknodes.basenodes import mknode
+from mknodes.basenodes import mktext
 from mknodes.pages import mkpage
-from mknodes.utils import log, pathhelpers, reprhelpers
-
-
-EXAMPLE_URL = "https://raw.githubusercontent.com/phil65/mknodes/main/README.md"
+from mknodes.utils import log, pathhelpers
 
 
 logger = log.get_logger(__name__)
 
 
-class MkInclude(mknode.MkNode):
+class MkInclude(mktext.MkText):
     """Node to include the text of other Markdown files / MkNodes.
 
     This node only keeps a reference to given target and resolves it when needed.
@@ -25,11 +22,7 @@ class MkInclude(mknode.MkNode):
 
     ICON = "octicons/file-symlink-file-24"
 
-    def __init__(
-        self,
-        target: str | os.PathLike | mknode.MkNode,
-        **kwargs: Any,
-    ):
+    def __init__(self, target: str | os.PathLike | mktext.MkText, **kwargs: Any):
         """Constructor.
 
         Arguments:
@@ -39,27 +32,19 @@ class MkInclude(mknode.MkNode):
         super().__init__(**kwargs)
         self.target = target
 
-    def __repr__(self):
-        return reprhelpers.get_repr(self, target=self.target)
-
-    def _to_markdown(self) -> str:  # type: ignore[return]
+    @property
+    def text(self) -> str:
         match self.target:
             case os.PathLike() | str():
-                return pathhelpers.load_file_cached(str(self.target))
-            case mknode.MkNode():
+                return pathhelpers.load_file_cached(os.fspath(self.target))
+            case mktext.MkText():
                 return str(self.target)
             case _:
                 raise TypeError(self.target)
 
-    @classmethod
-    def create_example_page(cls, page):
-        import mknodes as mk
-
-        node = MkInclude(EXAMPLE_URL)
-        page += mk.MkReprRawRendered(node)
-
 
 if __name__ == "__main__":
     page = mkpage.MkPage(content="test")
-    include = MkInclude(target=EXAMPLE_URL)
+    url = "https://raw.githubusercontent.com/phil65/mknodes/main/README.md"
+    include = MkInclude(target=url)
     print(include)
