@@ -4,7 +4,7 @@ from typing import Any
 
 from mknodes.basenodes import mktext
 from mknodes.info import license
-from mknodes.utils import log, reprhelpers
+from mknodes.utils import log
 
 
 logger = log.get_logger(__name__)
@@ -33,29 +33,18 @@ class MkLicense(mktext.MkText):
             kwargs: Keyword arguments passed to parent
         """
         super().__init__(**kwargs)
-        self.license = license_type
-
-    def __repr__(self):
-        return reprhelpers.get_repr(self, license=self.license, _filter_empty=True)
+        self.license_type = license_type
 
     @property
     def text(self):
-        if self.license:
-            lic = license.License.from_name(self.license)
-            lic.resolve_by_distribution(self.ctx.metadata.distribution_name)
+        if self.license_type:
+            lic = license.License.from_name(self.license_type)
+            if self.ctx.metadata.distribution_name:
+                lic.resolve_by_distribution(self.ctx.metadata.distribution_name)
             return lic.content
         return self.ctx.metadata.license_text or ""
 
-    @classmethod
-    def create_example_page(cls, page):
-        import mknodes as mk
-
-        node = MkLicense()
-        page += mk.MkReprRawRendered(node, header="### From project")
-        node = MkLicense("GPL-3.0")
-        page += mk.MkReprRawRendered(node, header="### Explicit")
-
 
 if __name__ == "__main__":
-    lic = MkLicense.with_default_context("GPL-3.0")
-    print(lic.text)
+    lic = MkLicense.with_context("GPL-3.0")
+    print(repr(lic))
