@@ -4,7 +4,6 @@ from __future__ import annotations
 
 from .node import Node
 from .filetreenode import FileTreeNode
-from .modulenode import ModuleNode
 from .noderesolver import NodeResolver
 
-__all__ = ["Node", "FileTreeNode", "ModuleNode", "NodeResolver"]
+__all__ = ["Node", "FileTreeNode", "NodeResolver"]
