@@ -3,18 +3,18 @@ from __future__ import annotations
 from collections.abc import Callable
 import pathlib
 
-from typing import cast
+from typing import Any, Self, cast
 
 from mknodes.data import treestyles
 from mknodes.treelib import node
-from mknodes.utils import fsspecpath, log
+from mknodes.utils import log
 
 
 logger = log.get_logger(__name__)
 
 
 class FileTreeNode(node.Node):
-    def __init__(self, path, **kwargs):
+    def __init__(self, path: pathlib.Path, **kwargs: Any):
         self.path = path
         self.name = self.path.name
         super().__init__(**kwargs)
@@ -25,7 +25,7 @@ class FileTreeNode(node.Node):
     @classmethod
     def from_folder(
         cls,
-        folder: pathlib.Path | fsspecpath.FsSpecPath,
+        folder: pathlib.Path,
         *,
         predicate: Callable | None = None,
         exclude_folders: list[str] | None = None,
@@ -33,7 +33,7 @@ class FileTreeNode(node.Node):
         max_items: int | None = None,
         maximum_depth: int | None = None,
         parent: FileTreeNode | None = None,
-    ):
+    ) -> Self:
         node = cls(folder, parent=parent)
         children = list(folder.iterdir())
         if sort:
@@ -66,7 +66,7 @@ class FileTreeNode(node.Node):
         return node
 
     def get_folder_count(self) -> int:
-        return sum(i.path.is_folder() for i in self.descendants)
+        return sum(i.path.is_dir() for i in self.descendants)
 
     def get_file_count(self) -> int:
         return sum(i.path.is_file() for i in self.descendants)
@@ -78,7 +78,7 @@ class FileTreeNode(node.Node):
         show_icon: bool = True,
     ) -> str:
         lines = []
-        for pre_str, fill_str, _node in self.yield_tree(
+        for pre_str, fill_str, _node in self._yield_tree(
             max_depth=max_depth,
             style=style or "ascii",
         ):
@@ -94,13 +94,15 @@ class FileTreeNode(node.Node):
 
 
 if __name__ == "__main__":
+    import upath
+
     folder = FileTreeNode.from_folder(
-        pathlib.Path(),
+        upath.UPath("github://mknodes/docs/", org="phil65", repo="mknodes"),
         exclude_folders=["__pycache__", ".git", ".mypy_cache"],
         sort=False,
         maximum_depth=2,
     )
-    logger.warning(folder.get_tree_repr())
+    print(folder.get_tree_repr())
     # for node in folder.descendants:
     #     logger.warning(node.displayable())
     # print(get_tree_repr(folder))
