@@ -73,7 +73,7 @@ def get_package_map() -> Mapping[str, list[str]]:
 
 
 @functools.cache
-def distribution_to_package(dist: str):
+def distribution_to_package(dist: str) -> str:
     """Return the top-level package for given distribution.
 
     Arguments:
@@ -84,7 +84,7 @@ def distribution_to_package(dist: str):
 
 
 @functools.cache
-def get_marker(marker):
+def get_marker(marker) -> Marker:
     return Marker(marker)
 
 
@@ -105,6 +105,15 @@ def get_extras(markers: list) -> list[str]:
     return extras
 
 
+def import_dotted_path(path: str) -> Any:
+    if ":" in path:
+        mod_name, kls_name = path.split(":")
+    else:
+        mod_name, kls_name = path, None
+    mod = importlib.import_module(mod_name)
+    return getattr(mod, kls_name) if kls_name else mod
+
+
 @dataclasses.dataclass
 class EntryPoint:
     """EntryPoint including imported module."""
@@ -115,12 +124,7 @@ class EntryPoint:
 
     def load(self) -> Any:
         """Import and return the EntryPoint object."""
-        if ":" in self.dotted_path:
-            mod_name, kls_name = self.dotted_path.split(":")
-        else:
-            mod_name, kls_name = self.dotted_path, None
-        mod = importlib.import_module(mod_name)
-        return getattr(mod, kls_name) if kls_name else mod
+        return import_dotted_path(self.dotted_path)
 
     @property
     def module(self) -> str:
@@ -152,7 +156,8 @@ def get_entry_points(
         eps = [i for i in _get_entry_points(dist) if i.group == group or not group]
     else:
         kw_args = dict(group=group, **kwargs) if group else kwargs
-        eps = _get_entry_points(**kw_args)
+        eps = [i for ls in _get_entry_points(**kw_args).values() for i in ls]
+
     return EntryPointMap(eps)
 
 
@@ -164,20 +169,8 @@ class EntryPointMap(collections.defaultdict):
                 ep = EntryPoint(name=ep.name, dotted_path=ep.value, group=ep.group)
             self[ep.group].append(ep)
 
-    @classmethod
-    def from_system(cls):
-        eps = _get_entry_points()
-        kls = cls()
-        for group in eps.groups:
-            kls[group] = [
-                EntryPoint(name=ep.name, dotted_path=ep.value, group=ep.group)
-                for ep in eps.select(group=group)
-            ]
-        # kls.update([i for ls in eps.select() for i in ls])
-        return kls
-
     @property
-    def all_eps(self):
+    def all_eps(self) -> list[EntryPoint]:
         return [i for ls in self.values() for i in ls]
 
     def by_name(self, name: str) -> EntryPoint | None:
@@ -194,7 +187,7 @@ class Dependency:
         self._marker = name
 
     @property
-    def marker(self):
+    def marker(self) -> Marker | None:
         return (
             get_marker(self._marker.split(";", maxsplit=1)[-1])
             if ";" in self._marker
@@ -202,7 +195,7 @@ class Dependency:
         )
 
     @functools.cached_property
-    def extras(self):
+    def extras(self) -> list[str]:
         return get_extras(self.marker._markers) if self.marker else []
 
     def __repr__(self):
@@ -221,6 +214,31 @@ def list_installed_packages() -> dict[str, str]:
     return {i.project_name: i.key for i in pkg_resources.working_set}
 
 
+@functools.cache
+def list_pip_packages(
+    local_only: bool = True,
+    user_only: bool = False,
+    include_editables: bool = True,
+    editables_only: bool = False,
+):
+    # import warnings
+
+    # with warnings.catch_warnings():
+    #     warnings.simplefilter("ignore")
+
+    from pip._internal.metadata import pkg_resources
+
+    return list(
+        pkg_resources.Environment.from_paths(None).iter_installed_distributions(
+            local_only=local_only,
+            skip=(),
+            user_only=user_only,
+            include_editables=include_editables,
+            editables_only=editables_only,
+        )
+    )
+
+
 if __name__ == "__main__":
     eps = list_installed_packages()
     print(eps)
