@@ -5,14 +5,71 @@ import functools
 import os
 import pathlib
 import posixpath
+import re
 import shutil
 
+import upath
+
+from upath import core, registry
+
 from mknodes.utils import log
 
 
+_RFC_3986_PATTERN = re.compile(r"^[A-Za-z][A-Za-z0-9+\-+.]*://")
+
 logger = log.get_logger(__name__)
 
 
+class _GitHubAccessor(core._FSSpecAccessor):
+    """FSSpecAccessor for GitHub."""
+
+    def _format_path(self, path: core.UPath) -> str:
+        """Remove the leading slash from the path."""
+        return path._path.lstrip("/")
+
+
+class GitHubPath(core.UPath):
+    """GitHubPath supporting the fsspec.GitHubFileSystem."""
+
+    _default_accessor = _GitHubAccessor
+
+
+cls_path = "mknodes.utils.pathhelpers.GitHubPath"
+registry._Registry.known_implementations["github"] = cls_path
+
+
+def fsspec_copy(
+    source_path: str | os.PathLike,
+    output_path: str | os.PathLike,
+    exist_ok: bool = True,
+):
+    """Copy source_path to output_path, making sure any parent directories exist.
+
+    The output_path may be a directory.
+
+    Arguments:
+        source_path: File to copy
+        output_path: path where file should get copied to.
+        exist_ok: Whether exception should be raised in case stuff would get overwritten
+    """
+    import fsspec
+
+    if isinstance(source_path, upath.UPath):
+        src = fsspec.FSMap(source_path.path, source_path.fs)
+    else:
+        src = fsspec.get_mapper(str(source_path))
+    if isinstance(output_path, upath.UPath):
+        target = fsspec.FSMap(output_path.path, output_path.fs)
+    else:
+        target = fsspec.get_mapper(str(output_path))
+    if not exist_ok and any(key in target for key in src):
+        msg = "cannot overwrite if exist_ok is set to False"
+        raise RuntimeError(msg)
+    for k in src:
+        target[k] = src[k]
+
+
+#
 def copy(
     source_path: str | os.PathLike,
     output_path: str | os.PathLike,
@@ -27,18 +84,33 @@ def copy(
         output_path: path where file should get copied to.
         exist_ok: Whether exception should be raised in case stuff would get overwritten
     """
-    output_path = pathlib.Path(output_path)
-    source_path = pathlib.Path(source_path)
-    output_path.parent.mkdir(parents=True, exist_ok=exist_ok)
-    if source_path.is_dir():
-        if output_path.is_dir():
+    output_p = upath.UPath(output_path)
+    source_p = upath.UPath(source_path)
+    output_p.parent.mkdir(parents=True, exist_ok=exist_ok)
+    if source_p.is_dir():
+        if output_p.is_dir():
             msg = "Cannot copy folder to file!"
             raise RuntimeError(msg)
-        shutil.copytree(source_path, output_path, dirs_exist_ok=exist_ok)
+        shutil.copytree(source_p, output_p, dirs_exist_ok=exist_ok)
     else:
-        if output_path.is_dir():
-            output_path = output_path / source_path.name
-        shutil.copyfile(source_path, output_path)
+        if output_p.is_dir():
+            output_p = output_p / source_p.name
+        shutil.copyfile(source_p, output_p)
+
+
+def clean_directory(directory: str | os.PathLike, remove_hidden: bool = False) -> None:
+    """Remove the content of a directory recursively but not the directory itself."""
+    folder_to_remove = upath.UPath(directory)
+    if not folder_to_remove.exists():
+        return
+    for entry in folder_to_remove.iterdir():
+        if entry.name.startswith(".") and not remove_hidden:
+            continue
+        path = folder_to_remove / entry
+        if path.is_dir():
+            shutil.rmtree(path, True)
+        else:
+            path.unlink()
 
 
 def write_file(content: str | bytes, output_path: str | os.PathLike):
@@ -48,11 +120,11 @@ def write_file(content: str | bytes, output_path: str | os.PathLike):
         content: Content to write
         output_path: path where file should get written to.
     """
-    output_path = pathlib.Path(output_path)
-    output_path.parent.mkdir(parents=True, exist_ok=True)
+    output_p = upath.UPath(output_path)
+    output_p.parent.mkdir(parents=True, exist_ok=True)
     mode = "wb" if isinstance(content, bytes) else "w"
     encoding = None if "b" in mode else "utf-8"
-    with output_path.open(mode=mode, encoding=encoding) as f:
+    with output_p.open(mode=mode, encoding=encoding) as f:
         f.write(content)
 
 
@@ -66,9 +138,17 @@ def write_files(mapping: Mapping[str | os.PathLike, str | bytes]):
         write_file(v, k)
 
 
+# deprecated
 def find_file_in_folder_or_parent(
     filename: str | pathlib.Path,
     folder: os.PathLike | str = ".",
+) -> pathlib.Path | None:
+    return find_cfg_for_folder(filename, folder)
+
+
+def find_cfg_for_folder(
+    filename: str | pathlib.Path,
+    folder: os.PathLike | str = ".",
 ) -> pathlib.Path | None:
     """Search for a file with given name in folder and its parent folders.
 
@@ -76,10 +156,15 @@ def find_file_in_folder_or_parent(
         filename: File to search
         folder: Folder to start searching from
     """
-    path = pathlib.Path(folder).absolute()
-    while not (path / filename).exists() and len(path.parts) > 1:
+    if folder and folder != ".":
+        path = upath.UPath(folder).absolute() / filename
+    else:
+        path = upath.UPath(filename).absolute()
+    while len(path.parts) > 1:
         path = path.parent
-    return file if (file := (path / filename)).exists() else None
+        if (file := path / filename).exists():
+            return file
+    return None
 
 
 @functools.cache
@@ -89,6 +174,15 @@ def load_file_cached(path: str | os.PathLike) -> str:
     return pathlib.Path(path).read_text(encoding="utf-8")
 
 
+def is_fsspec_url(url: str | os.PathLike[str]) -> bool:
+    """Returns true if the given URL looks like something fsspec can handle."""
+    return (
+        isinstance(url, str)
+        and bool(_RFC_3986_PATTERN.match(url))
+        and not url.startswith(("http://", "https://"))
+    )
+
+
 def download_from_github(
     org: str,
     repo: str,
@@ -103,11 +197,12 @@ def download_from_github(
     token = token or os.environ.get("GITHUB_TOKEN")
     if token and not username:
         token = None
-    destination = pathlib.Path(destination)
-    destination.mkdir(exist_ok=True, parents=True)
+    dest = upath.UPath(destination)
+    dest.mkdir(exist_ok=True, parents=True)
     fs = fsspec.filesystem("github", org=org, repo=repo)
     logger.info("Copying files from Github: %s", path)
-    fs.get(fs.ls(str(path)), destination.as_posix(), recursive=recursive)
+    files = fs.ls(str(path))
+    fs.get(files, dest.as_posix(), recursive=recursive)
 
 
 @functools.cache
@@ -188,5 +283,4 @@ def relative_url(url_a: str, url_b: str) -> str:
 
 
 if __name__ == "__main__":
-    file = download_from_github("phil65", "mknodes", "mknodes", "testus/")
-    print(file)
+    file = find_file_in_folder_or_parent("github://phil65:mknodes@main/docs/icons.jinja")
