@@ -78,7 +78,7 @@ class CSSFile:
     onload: str | None = None
 
     def __repr__(self):
-        return reprhelpers.dataclass_repr(self)
+        return reprhelpers.get_dataclass_repr(self)
 
     def __str__(self):
         return self.link
@@ -115,7 +115,7 @@ class JSFile:
     is_library: bool = False
 
     def __repr__(self):
-        return reprhelpers.dataclass_repr(self)
+        return reprhelpers.get_dataclass_repr(self)
 
     def __str__(self):
         return self.link
@@ -157,6 +157,9 @@ class TextResource:
             else f"{hashed}{self.EXTENSION}"
         )
 
+    def get_asset(self) -> Asset:
+        return Asset(filename=self.resolved_filename, content=self.content)
+
     def __hash__(self):
         return hash(self.content)
 
@@ -176,6 +179,9 @@ class CSSText(TextResource):
         # content = self.content.replace("\n", "")
         return f"<style>\n{self.content}\n</style>"
 
+    def get_cssfile(self) -> CSSFile:
+        return CSSFile(link=self.resolved_filename)
+
 
 @dataclasses.dataclass(frozen=True, repr=False)
 class JSText(TextResource):
@@ -200,9 +206,6 @@ class JSText(TextResource):
             is_library=self.is_library,
         )
 
-    def get_asset(self) -> Asset:
-        return Asset(filename=self.resolved_filename, content=self.content)
-
 
 class Asset:
     """An asset resource."""
