@@ -3,11 +3,13 @@ from __future__ import annotations
 import mknodes as mk
 
 
-EXPECTED_IN_ANNOTATIONS = """1.  ::: mknodes.basenodes._mkdocstrings.MkDocStrings.__init__
+EXPECTED_IN_ANNOTATIONS = """\
+1.  ::: mknodes.basenodes._mkdocstrings.MkDocStrings.__init__
         options:
           docstring_section_style: 'list'
           show_root_heading: True
-    """ + "\n"  # noqa: ISC003
+
+"""
 
 
 def test_docstrings():
